summaryrefslogtreecommitdiff
path: root/chromium/third_party/pdfium/public/fpdfview.h
diff options
context:
space:
mode:
authorAllan Sandfeld Jensen <allan.jensen@qt.io>2017-04-05 14:08:31 +0200
committerAllan Sandfeld Jensen <allan.jensen@qt.io>2017-04-11 07:46:53 +0000
commit6a4cabb866f66d4128a97cdc6d9d08ce074f1247 (patch)
treeab00f70a5e89278d6a0d16ff0c42578dc4d84a2d /chromium/third_party/pdfium/public/fpdfview.h
parente733310db58160074f574c429d48f8308c0afe17 (diff)
downloadqtwebengine-chromium-6a4cabb866f66d4128a97cdc6d9d08ce074f1247.tar.gz
BASELINE: Update Chromium to 57.0.2987.144
Change-Id: I29db402ff696c71a04c4dbaec822c2e53efe0267 Reviewed-by: Peter Varga <pvarga@inf.u-szeged.hu>
Diffstat (limited to 'chromium/third_party/pdfium/public/fpdfview.h')
-rw-r--r--chromium/third_party/pdfium/public/fpdfview.h52
1 files changed, 45 insertions, 7 deletions
diff --git a/chromium/third_party/pdfium/public/fpdfview.h b/chromium/third_party/pdfium/public/fpdfview.h
index 469053c4e84..7378d5f9b11 100644
--- a/chromium/third_party/pdfium/public/fpdfview.h
+++ b/chromium/third_party/pdfium/public/fpdfview.h
@@ -39,6 +39,8 @@ typedef void* FPDF_PAGERANGE;
typedef void* FPDF_PATH;
typedef void* FPDF_RECORDER;
typedef void* FPDF_SCHHANDLE;
+typedef void* FPDF_STRUCTELEMENT;
+typedef void* FPDF_STRUCTTREE;
typedef void* FPDF_TEXTPAGE;
#ifdef PDF_ENABLE_XFA
@@ -211,7 +213,8 @@ DLLEXPORT void STDCALL FPDF_DestroyLibrary();
DLLEXPORT void STDCALL FPDF_SetSandBoxPolicy(FPDF_DWORD policy,
FPDF_BOOL enable);
-#if defined(_WIN32) && defined(PDFIUM_PRINT_TEXT_WITH_GDI)
+#if defined(_WIN32)
+#if defined(PDFIUM_PRINT_TEXT_WITH_GDI)
// Pointer to a helper function to make |font| with |text| of |text_length|
// accessible when printing text with GDI. This is useful in sandboxed
// environments where PDFium's access to GDI may be restricted.
@@ -237,7 +240,20 @@ FPDF_SetTypefaceAccessibleFunc(PDFiumEnsureTypefaceCharactersAccessible func);
// Return value:
// None.
DLLEXPORT void STDCALL FPDF_SetPrintTextWithGDI(FPDF_BOOL use_gdi);
-#endif
+#endif // PDFIUM_PRINT_TEXT_WITH_GDI
+
+// Function: FPDF_SetPrintPostscriptLevel
+// Set postscript printing level when printing on Windows.
+// Experimental API.
+// Parameters:
+// postscript_level - 0 to disable postscript printing,
+// 2 to print with postscript level 2,
+// 3 to print with postscript level 3.
+// All other values are invalid.
+// Return value:
+// True if successful, false if unsucessful (typically invalid input).
+DLLEXPORT FPDF_BOOL STDCALL FPDF_SetPrintPostscriptLevel(FPDF_BOOL use_gdi);
+#endif // defined(_WIN32)
// Function: FPDF_LoadDocument
// Open and load a PDF document.
@@ -594,11 +610,11 @@ DLLEXPORT void STDCALL FPDF_RenderPage(HDC dc,
// 1 (rotated 90 degrees clockwise)
// 2 (rotated 180 degrees)
// 3 (rotated 90 degrees counter-clockwise)
// flags - 0 for normal display, or combination of flags
// defined above. With FPDF_ANNOT flag, it renders all
// annotations that does not require user-interaction,
// which are all annotations except widget and popup
// annotations.
// Return value:
// None.
DLLEXPORT void STDCALL FPDF_RenderPageBitmap(FPDF_BITMAP bitmap,
@@ -610,6 +626,28 @@ DLLEXPORT void STDCALL FPDF_RenderPageBitmap(FPDF_BITMAP bitmap,
int rotate,
int flags);
+// Function: FPDF_RenderPageBitmapWithMatrix
+// Render contents of a page to a device independent bitmap.
+// Parameters:
+// bitmap - Handle to the device independent bitmap (as the
+// output buffer). The bitmap handle can be created
+// by FPDFBitmap_Create.
+// page - Handle to the page. Returned by FPDF_LoadPage
+// matrix - The transform matrix.
+// clipping - The rect to clip to.
+// flags - 0 for normal display, or combination of the Page
+// Rendering flags defined above. With the FPDF_ANNOT
+// flag, it renders all annotations that do not require
+// user-interaction, which are all annotations except
+// widget and popup annotations.
+// Return value:
+// None.
+DLLEXPORT void STDCALL FPDF_RenderPageBitmapWithMatrix(FPDF_BITMAP bitmap,
+ FPDF_PAGE page,
+ const FS_MATRIX* matrix,
+ const FS_RECTF* clipping,
+ int flags);
+
#ifdef _SKIA_SUPPORT_
DLLEXPORT FPDF_RECORDER STDCALL FPDF_RenderPageSkp(FPDF_PAGE page,
int size_x,
@@ -594,11 +610,11 @@ DLLEXPORT void STDCALL FPDF_RenderPage(HDC dc,
// 2 (rotated 180 degrees)
// 3 (rotated 90 degrees counter-clockwise)
-// flags - 0 for normal display, or combination of flags
-// defined above. With FPDF_ANNOT flag, it renders all
-// annotations that does not require user-interaction,
-// which are all annotations except widget and popup
-// annotations.
+// flags - 0 for normal display, or combination of the Page
+// Rendering flags defined above. With the FPDF_ANNOT
+// flag, it renders all annotations that do not require
+// user-interaction, which are all annotations except
+// widget and popup annotations.
// Return value:
// None.